package tech.nevets;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.util.StringTokenizer;

/**
 * This class will extract a secret word from the string in the <a href="./secret.txt">secret.txt</a> file.
 * Ensure you have created a secret.txt file, with text, in the same directory as the program.
 */
public class STSecretMessage {
    /**
     * Main method where everything takes place
     * @param args default args variable
     * @throws FileNotFoundException FileReader will error out if the <a href="./secret.txt">secret.txt</a> file does not exist.
     */
    public static void main(String[] args) throws FileNotFoundException {
        // The following 4 lines opens a buffered reader from a file reader
        // Then it creates the string by appending all the lines into a single StringBuilder
        // To achieve this, I used Java's built-in Streams API
        BufferedReader reader = new BufferedReader(new FileReader("./secret.txt"));
        StringBuilder sb = new StringBuilder();
        reader.lines().forEach(sb::append);
        String secretTextRaw = sb.toString();

        // Below loops through the StringTokenizer object while counting each fifth interval
        StringTokenizer tokenizer = new StringTokenizer(secretTextRaw, " ", false);
        StringBuilder secret = new StringBuilder();
        // Here we set the counter to 4 to start with the first word in the secret text.
        int count = 4;
        // I initialize the String variable with the first token
        // For the boolean check I make sure there are still tokens left in the buffer, preventing an exception.
        // Finally, I update the String variable with the next token.
        for (String s = tokenizer.nextToken(); tokenizer.countTokens() > 0; s = tokenizer.nextToken()) {
            // On the fifth interval it will append the first char of the token to the secret StringBuilder
            // Then reset the counter
            if (count == 4) {
                secret.append(s.charAt(0));
                count = 0;
            // On the off intervals, it increments the counter and loops again.
            } else {
                count++;
            }
        }
        // This line converts the StringBuilder to a string, then turns it to all caps and writes it to the console.
        System.out.println(secret.toString().toUpperCase());
    }
}
